@@ -9,7 +9,8 @@ mgmsampler <- function(factors,
                        N,
                        nIter = 250,
                        pbar = TRUE,
-                       divWarning = 10^3)
+                       divWarning = 10^3,
+                       returnChains = FALSE)
   
   
 {
@@ -25,29 +26,32 @@ mgmsampler <- function(factors,
   
   # Check whether level are correctly specified according to type
   if(any(level[type!="c"] != 1)) stop("The levels of all non-categorical variable has to be specified as c(1).")
-
+  
   # Check whether all interactions are specified in the correct dimension
   for(ord in 1:n_order) {
     
     rows_ord <- nrow(factors[[ord]])
     
-    for(row in 1:rows_ord) {
-      
-      if(!all(level[factors[[ord]][row, ]] == dim(interactions[[ord]][[row]]))) {
-        stop(paste0("The dimensions of the interaction ",
-                    paste0(factors[[ord]][row, ], collapse = "-"), 
-                           " is specified incorrectly. Please correct the 'interactions' argument."
-                    ))
-      }
-
-    } # end for: rows (interactions)
+    # Only check if there are actually factors of a given dimension
+    if(!is.null(rows_ord)) {
+      for(row in 1:rows_ord) {
+        
+        if(!all(level[factors[[ord]][row, ]] == dim(interactions[[ord]][[row]]))) {
+          stop(paste0("The dimensions of the interaction ",
+                      paste0(factors[[ord]][row, ], collapse = "-"), 
+                      " is specified incorrectly. Please correct the 'interactions' argument."
+          ))
+        }
+        
+      } # end for: rows (interactions)      
+    } # end if: 0> rows?
+    
   } # end for: ord
-
   
   # Are all parameters specified as matrices?
   for(i in 1:n_order) {
     n_ints <- length(interactions[[i]])
-    for(row in 1:n_ints) if(class( interactions[[i]][[row]]) != "matrix") stop("The parameters of each interaction have to be provided as k-dimensional array.")
+    if(n_ints>0) for(row in 1:n_ints) if(!(class( interactions[[i]][[row]]) %in% c("array","matrix"))) stop("The parameters of each interaction have to be provided as k-dimensional array.")
   }
   
   
@@ -112,7 +116,8 @@ mgmsampler <- function(factors,
   
   # Create Output Object
   mgmsamp_obj <- list('call' = NULL,
-                      'data' = NULL)
+                      'data' = NULL, 
+                      'chains' = NULL)
   
   # Copy the call
   mgmsamp_obj$call <- list('factors' = factors,
@@ -126,7 +131,7 @@ mgmsampler <- function(factors,
                            'pbar' = pbar,
                            'divWarning' = divWarning)
   
-
+  
   # ---------- Optional: Enforce positive definite Gaussian subgraph ----------
   
   # browser()
@@ -135,6 +140,9 @@ mgmsampler <- function(factors,
   
   if(pbar==TRUE) pb <- txtProgressBar(min = 0, max=N, initial=0, char="-", style = 3)
   
+  # Return chains of Gibbs sampler
+  if(returnChains) chains <- array(NA, dim = c(N, nIter, p))
+  
   data <- matrix(NA, nrow = N, ncol = p)
   
   for(case in 1:N) {
@@ -221,7 +229,7 @@ mgmsampler <- function(factors,
             
           } # end loop: ord
           
-
+          
           # Compute Natural Parameter (collapse and sum all interaction terms)
           natPar <- sum(unlist(l_natPar))
           
@@ -236,7 +244,7 @@ mgmsampler <- function(factors,
           
         } #end if: v == continuous?
         
-
+        
         # A) ------ Categorical conditional ------
         
         if(type[v] == 'c') {
@@ -294,7 +302,7 @@ mgmsampler <- function(factors,
                     
                     # get the parameter for ord-interaction out the the ord-order parameter array
                     row_int <- interactions[[ord]][[row]][m_fill_in]
-      
+                    
                     # multiply it by continuous variables if in interaction and save in list
                     l_row_terms[[row_counter]] <- prod(get_cont[-which(f_ind == v)]) * row_int
                     
@@ -315,28 +323,21 @@ mgmsampler <- function(factors,
             
           } # end: for cat
           
-          # if(v == 2) browser()
           
           v_probabilities <- exp(v_Potential) / sum(exp(v_Potential)) # calc probability for each category
           sampling_seq[iter, v] <- sample(1:level[v], size = 1, prob = v_probabilities) # sample from multinomial distribution
           
         }
         
-        # print(v)
-        
       } # end for: v
       
-      # print(iter)
-      
     } # end for: iter
     
     
+    if(returnChains) chains[case, , ] <- sampling_seq
     
     data[case, ] <- sampling_seq[nIter, ] # Fill in last sampling iteration
     
-    # browser()
-    
-    
     if(pbar==TRUE) setTxtProgressBar(pb, case)
     
   } # end for: case
@@ -346,6 +347,7 @@ mgmsampler <- function(factors,
   # ---------- Export ----------
   
   mgmsamp_obj$data <- data
+  if(returnChains) mgmsamp_obj$chains <- chains
   
   return(mgmsamp_obj)
   
